evaluate_plan

Function evaluate_plan 

pub fn evaluate_plan<F: Filterable + ?Sized>(
    rules: &[FilterRule],
    msg: &F,
    ctx: &EvalContext<'_>,
    regex_cache: &RegexCache,
) -> EvalOutcome
Evaluate rules against a message and resolve them into execution-ready outcomes.

Like collect_matches this is first-match-wins, but the returned plan additionally resolves the actions that need runtime context:

Pure and synchronous: no I/O, never panics.