MailEnvelope

Struct MailEnvelope 

pub struct MailEnvelope {
    pub from: String,
    pub to: String,
    pub cc: String,
    pub subject: String,
    pub body: String,
    pub has_attachment: bool,
    pub headers: Vec<(String, String)>,
    pub envelope_from: Option<String>,
    pub envelope_to: Option<String>,
}
A simple envelope of the fields a filter engine needs.

A ready-made Filterable implementation for callers that do not want to implement the trait for their own message type.

Fields

from: String

First From address email.

to: String

First To address email.

cc: String

First Cc address email.

subject: String

Subject header.

body: String

Body text.

has_attachment: bool

Whether the message has attachments.

headers: Vec<(String, String)>

Raw headers (name -> value) for Header conditions.

envelope_from: Option<String>

Envelope sender (SMTP MAIL FROM) for Envelope conditions and vacation reply routing; None when not supplied.

envelope_to: Option<String>

Envelope recipient (SMTP RCPT TO); None when not supplied.